# Data

::: inspeqtor.data

::: inspeqtor.data.QubitInformation

::: inspeqtor.data.DataBundled

::: inspeqtor.data.ExpectationValue

::: inspeqtor.data.ExperimentalData

::: inspeqtor.data.ExperimentConfiguration

::: inspeqtor.data.get_observable_operator

::: inspeqtor.data.get_initial_state

::: inspeqtor.data.get_complete_expectation_values

::: inspeqtor.data.load_data_from_path

::: inspeqtor.data.save_data_to_path

::: inspeqtor.data.LoadedData

::: inspeqtor.data.prepare_data

## Library

::: inspeqtor.data.library

::: inspeqtor.data.library.get_predefined_data_model_m1

::: inspeqtor.data.library.generate_single_qubit_experimental_data

::: inspeqtor.data.library.get_mock_qubit_information
